pub struct BlockPlacement {
pub floor: bool,
pub ceiling: bool,
pub sides: bool,
pub rotatable: bool,
pub centered: bool,
pub rotation_transform: Option<Transform>,
}Expand description
Defines how a block can be placed.
Fields
floor: boolSet if the block can be placed by clicking the top face of a block
ceiling: boolSet if the block can be placed by clicking the bottom face of a block
sides: boolSet if the block can be placed by clicking the sides of blocks
rotatable: boolSet if the block should be rotated when placed.
centered: boolIf ‘rotatable’ is set, this allows a block to be placed without rotation if it is placed on the Top or Bottom face of a block.
rotation_transform: Option<Transform>Set if a transform should be applied when rotated.