pub struct Blocks { /* private fields */ }Expand description
The configurations and ids of the blocks in the game.
Implementations
Sourceimpl Blocks
impl Blocks
Sourcepub fn get() -> &'static Self
pub fn get() -> &'static Self
WARN: Panics if used during startup. If you need it during startup, use the Resource instead.
pub fn get_config(&self, block_id: &BlockId) -> &Block
pub fn get_config_mut(&mut self, block_id: &BlockId) -> &mut Block
pub fn get_id(&self, block_name: &str) -> BlockId
pub fn asset_ids(&self) -> HashMap<String, BlockId>
pub fn contains_block(&self, block_name: &str) -> bool